%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%define vnc_version 1.0.0

Name: 		x11-proto-devel
Summary:        Xorg X11 protocol specification headers
Version:        2024.1
Release:        %mkrel 6
Group:          Development/X11
License:        MIT
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/archive/individual/proto/xorgproto-%{version}.tar.xz
# FIXME: to be split:
Source31:       https://xf4vnc.sf.net/vncproto-%{vnc_version}.tar.bz2
BuildArch:      noarch

BuildRequires:  meson >= 0.43
BuildRequires:  x11-util-macros >= 1.0.1

%if !%{bootstrap}
# For docs:
BuildRequires:  docbook-dtd412-xml
BuildRequires:  docbook-dtd45-xml
BuildRequires:  docbook-style-xsl
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  x11-sgml-doctools
%endif

BuildRequires:  python3

%description
X.Org X11 Protocol headers.

#-----------------------------------------------------------

%package -n x11-proto-doc

Summary:        Documentation for the X11 protocol and extensions
Group:          Development/X11
BuildArch:      noarch

%description -n x11-proto-doc
Documentation for the X11 protocol and extensions.

#-----------------------------------------------------------

%prep
%setup -q -n xorgproto-%version -a31

%build
%meson -Dlegacy=true
%meson_build

# vncproto is from cvs
pushd vncproto-*
aclocal
automake -a -c
autoconf
popd

for dir in vnc*/; do
pushd $dir
sed -i -e 's,^\(pkgconfigdir =\).*,\1 ${datadir}/pkgconfig,' Makefile.am
autoreconf -vfi
%configure --without-fop --build=%{_build}
%make_build
popd
done

%install
%meson_install
for dir in vnc*/; do
    if [ -d $dir ]; then
	pushd $dir
	%make_install
	popd
    fi
done

# refer to https://gitlab.freedesktop.org/xorg/proto/xorgproto/issues/10
# These headers refer to libX11 types and don't belong in this package.
# libX11 and libXvMC have been updated to supply these headers themselves
# now, so these are only useful for building older versions of those libraries.
# So let's drop conflicting files (mga#26176) as we build with "legacy" turned on:

# now in libx11 since release 1.6.9
rm -rf %{buildroot}%{_includedir}/X11/extensions/XKBgeom.h
# now in libXvMC since release 1.0.12
rm -rf %{buildroot}%{_includedir}/X11/extensions/vldXvMC.h

rm -rf %{buildroot}%{_datadir}/doc/xorgproto/*.txt
rm -rf %{buildroot}%{_datadir}/doc/xorgproto/PM_spec

%files
%{_includedir}/GL/glx*
%{_includedir}/GL/internal/*
%{_includedir}/X11/*.h
%{_includedir}/X11/dri/*
%{_includedir}/X11/extensions/*
%{_includedir}/X11/fonts/*
%{_includedir}/X11/PM/*
%{_datadir}/pkgconfig/*.pc

%files -n x11-proto-doc
%doc *.txt PM_spec


%changelog
* Tue Apr 02 2024 tv <tv> 2024.1-6.mga10
+ Revision: 2053998
- xorgproto 2024.1

* Tue Dec 19 2023 papoteur <papoteur> 2023.2-6.mga10
+ Revision: 2019409
- Mass Rebuild - Python 3.12

* Thu Dec 07 2023 wally <wally> 2023.2-5.mga10
+ Revision: 2014772
- rebuild for py3.12

* Tue Oct 17 2023 daviddavid <daviddavid> 2023.2-4.mga10
+ Revision: 1998224
- remove xcb-proto now splitted in its own pkg

* Tue Oct 17 2023 daviddavid <daviddavid> 2023.2-3.mga10
+ Revision: 1997883
- update xcb-proto to 1.16.0

* Thu Sep 21 2023 tv <tv> 2023.2-2.mga10
+ Revision: 1989077
- xorgproto 2023.2

* Wed Nov 02 2022 luigiwalser <luigiwalser> 2022.2-2.mga9
+ Revision: 1901812
- xcb-proto 1.15.2

* Sat Sep 24 2022 luigiwalser <luigiwalser> 2022.2-1.mga9
+ Revision: 1891878
- 2022.2

* Tue Apr 26 2022 luigiwalser <luigiwalser> 2022.1-1.mga9
+ Revision: 1854463
- 2022.1

* Thu Mar 24 2022 umeabot <umeabot> 2021.5-3.mga9
+ Revision: 1824647
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 2021.5-2.mga9
+ Revision: 1772020
- rebuild for python3.10

* Mon Nov 01 2021 tv <tv> 2021.5-1.mga9
+ Revision: 1753540
- xorgproto 2021.5

* Mon Jun 14 2021 tv <tv> 2021.4.99.2-1.mga9
+ Revision: 1730690
- Prerelease for inputproto snapshot

* Sun Mar 14 2021 wally <wally> 2021.3-2.mga9
+ Revision: 1702578
- rebuild for python 3.9

* Sun Feb 28 2021 tv <tv> 2021.3-1.mga9
+ Revision: 1693703
- xorgproto 2021.3

* Sat Oct 10 2020 tv <tv> 2020.1-2.mga8
+ Revision: 1633070
- xcb-proto-1.14.1

* Sat Apr 18 2020 tv <tv> 2020.1-1.mga8
+ Revision: 1568971
- 2020.1
+ danf <danf>
- Switch URLs from http: to https:

* Wed Mar 04 2020 tv <tv> 2019.2-4.mga8
+ Revision: 1553627
- xcb-proto 1.14

* Thu Feb 20 2020 umeabot <umeabot> 2019.2-3.mga8
+ Revision: 1547374
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 2019.2-2.mga8
+ Revision: 1488058
- drop conflicting header files with libx11-devel and libxvmc-devel pkgs (mga#26176)
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 22 2019 tv <tv> 2019.2-1.mga8
+ Revision: 1455205
- new release

* Wed Sep 04 2019 tv <tv> 2019.1-3.mga8
+ Revision: 1437082
- rebuild for python 3.8

* Sun Sep 01 2019 wally <wally> 2019.1-2.mga8
+ Revision: 1436084
- switch to python3

* Wed Jul 03 2019 tv <tv> 2019.1-1.mga8
+ Revision: 1417960
- new release

* Thu Apr 18 2019 umeabot <umeabot> 2018.4-4.mga7
+ Revision: 1392979
- Rebuild with meson 0.50.1

* Fri Sep 21 2018 umeabot <umeabot> 2018.4-3.mga7
+ Revision: 1292154
- Mageia 7 Mass Rebuild

* Fri Mar 09 2018 tv <tv> 2018.4-2.mga7
+ Revision: 1207521
- xcb-proto 1.13 (to be split...)
- new release

* Wed Feb 21 2018 tv <tv> 2018.3-3.mga7
+ Revision: 1203970
- enable legacy specs as we still have eg: a couple libxp users

* Wed Feb 21 2018 tv <tv> 2018.3-2.mga7
+ Revision: 1203919
- Switch to meson (note that using -Dlegacy=true would bring back fontcache as
  well as some proto we never shiped)

* Wed Feb 21 2018 tv <tv> 2018.3-1.mga7
+ Revision: 1203909
- Switch to merged protocol headers
- Drop evie & xprint headers
- keep vnc & xcb proto (to be split)
- bug: fontcache is not installed

* Sat Sep 09 2017 tv <tv> 7.7-29.mga7
+ Revision: 1152278
- fix build with latet rpm (bogus usage of %%setup -b instead of -a)

* Wed Feb 22 2017 wally <wally> 7.7-28.mga6
+ Revision: 1087415
- move pkgconfig .pc files to noarch location
- drop some ancient Mdv era conflicts

* Fri Jan 27 2017 tv <tv> 7.7-27.mga6
+ Revision: 1083576
- drop merged patch
- presentproto 1.1

* Sat Oct 15 2016 tv <tv> 7.7-26.mga6
+ Revision: 1060924
- use %%configure2_5x with --build=%%{_build} instead of %%old_configure

* Tue Oct 04 2016 tv <tv> 7.7-25.mga6
+ Revision: 1058660
- xproto 7.0.31

* Fri May 27 2016 tv <tv> 7.7-24.mga6
+ Revision: 1018867
- xproto 7.0.29

* Wed May 25 2016 luigiwalser <luigiwalser> 7.7-23.mga6
+ Revision: 1018527
- xcb-proto 1.12

* Fri Apr 08 2016 tv <tv> 7.7-22.mga6
+ Revision: 999353
- inputproto 2.3.2

* Sat Mar 12 2016 tv <tv> 7.7-21.mga6
+ Revision: 989388
- update videoproto
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Nov 10 2015 tv <tv> 7.7-19.mga6
+ Revision: 900993
- xproto 7.0.28

* Tue Sep 29 2015 tv <tv> 7.7-18.mga6
+ Revision: 885017
- use %%old_configure
- make it noarch thus fixing empty debuginfo

* Fri Jul 03 2015 tv <tv> 7.7-17.mga6
+ Revision: 849653
- xproto 7.0.28

* Sun Jun 21 2015 tv <tv> 7.7-16.mga6
+ Revision: 837501
- kbproto 1.0.7
- xproto 7.0.27

* Sat Jun 20 2015 tv <tv> 7.7-15.mga6
+ Revision: 835789
- update for xserver 1.17

* Sat Nov 29 2014 sander85 <sander85> 7.7-14.mga6
+ Revision: 799881
- Drop unneeded BR on fop

* Wed Oct 15 2014 umeabot <umeabot> 7.7-13.mga5
+ Revision: 742745
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.7-12.mga5
+ Revision: 690521
- Mageia 5 Mass Rebuild

* Thu Aug 21 2014 blino <blino> 7.7-11.mga5
+ Revision: 666114
- backport upstream presentproto patch to fix client libs on 64-bit machines

* Mon Aug 04 2014 blino <blino> 7.7-10.mga5
+ Revision: 659672
- xcb-proto 1.11
- buildrequire asciidoc to build inputproto doc
- remove docbook5-style-xsl buildrequire (a local build succeeds without it)

* Mon Jun 02 2014 tv <tv> 7.7-9.mga5
+ Revision: 630590
- inputproto 2.3.1
+ pterjan <pterjan>
- Rebuild for new Python

* Mon Apr 14 2014 tv <tv> 7.7-7.mga5
+ Revision: 614257
- xproto 7.0.26

* Mon Apr 14 2014 tv <tv> 7.7-6.mga5
+ Revision: 614145
- fonts-proto 2.1.3

* Tue Feb 04 2014 tv <tv> 7.7-5.mga5
+ Revision: 581923
- adjust file list
- do package present proto

* Tue Feb 04 2014 tv <tv> 7.7-4.mga5
+ Revision: 581723
- glproto 1.4.17

* Tue Feb 04 2014 tv <tv> 7.7-3.mga5
+ Revision: 581613
- adjust file list
- dri3proto 1.0
- xcb-proto 1.10
- xextproto 7.3.0
- xproto 7.0.25

* Sat Oct 19 2013 umeabot <umeabot> 7.7-3.mga4
+ Revision: 530656
- Mageia 4 Mass Rebuild

* Sat Jul 27 2013 tv <tv> 7.7-2.mga4
+ Revision: 458822
- videoproto 2.3.2

* Thu May 23 2013 tv <tv> 7.7-1.mga4
+ Revision: 425285
- adjust file list
- bump to 7.7
- inputproto 2.3
- xproto-7.0.24
- bump to 7.7
- inputproto 2.3
- xproto-7.0.24

* Fri Feb 08 2013 luigiwalser <luigiwalser> 7.6-24.mga3
+ Revision: 397212
- remove obsolete pre script

* Mon Jan 14 2013 umeabot <umeabot> 7.6-23.mga3
+ Revision: 386385
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 05 2012 tv <tv> 7.6-22.mga3
+ Revision: 302964
- xcb-proto 1.8

* Mon Jul 23 2012 tv <tv> 7.6-21.mga3
+ Revision: 273822
- gl 1.4.16
- randr 1.4.0

* Thu Jul 12 2012 tv <tv> 7.6-20.mga3
+ Revision: 270197
- dri2proto 2.8

* Tue May 29 2012 tv <tv> 7.6-19.mga3
+ Revision: 249368
- bigreqs_version 1.1.1
- fonts_version 2.1.1
- record_version 1.14.1
- scrnsaver_version 1.2.1
- xcmisc_version 1.2.1
- xext_version 7.2.0
- xproto_version 7.0.22

* Mon May 28 2012 colin <colin> 7.6-18.mga3
+ Revision: 248390
- Bump inputproto to 2.2

* Wed Feb 01 2012 tv <tv> 7.6-17.mga2
+ Revision: 203747
- input_version 2.1

* Tue Jan 31 2012 tv <tv> 7.6-16.mga2
+ Revision: 203676
- reenable doc

* Sun Jan 29 2012 tv <tv> 7.6-15.mga2
+ Revision: 203072
- glproto-1.4.15
- temporary disable docs

* Sat Jan 28 2012 fwang <fwang> 7.6-14.mga2
+ Revision: 202575
- disable fop build
- add ore br
+ tv <tv>
- BR docbook-style-xsl
- update xcb-proto to 1.7
- make the huge doc subpackage be noarch

* Thu Jun 30 2011 tv <tv> 7.6-12.mga2
+ Revision: 116233
- update file list
- glproto-1.4.14
- dri2proto-2.6

* Wed Jun 29 2011 tv <tv> 7.6-11.mga2
+ Revision: 116153
- xproto-7.0.22

* Fri Jun 17 2011 tv <tv> 7.6-10.mga2
+ Revision: 108553
- fix file list
- inputproto-2.0.2
- resourceproto-1.2.0

* Tue Apr 12 2011 tv <tv> 7.6-9.mga1
+ Revision: 83565
- applewmproto-1.4.2
- fixesproto-5.0

* Fri Apr 01 2011 tv <tv> 7.6-8.mga1
+ Revision: 79629
- xproto 7.0.21

* Tue Mar 01 2011 tv <tv> 7.6-7.mga1
+ Revision: 62134
- xextproto-7.2.0

* Fri Jan 28 2011 dmorgan <dmorgan> 7.6-6.mga1
+ Revision: 43007
- Disable bootstrap
+ rtp <rtp>
- disable fop on arm/mips as it's using java

* Mon Jan 17 2011 blino <blino> 7.6-5.mga1
+ Revision: 20920
- build with bootstrap again (and with new python)
- rebuild without bootstrap

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-4.mga1
+ Revision: 6363
- Remove workaround

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-3.mga1
+ Revision: 6333
- Fix else statement
- Bump release
- Enable the provides for the moment

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-2.mga1
+ Revision: 6322
- Rebuild

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-1.mga1
+ Revision: 6266
- Fix file List
- Fix file List
- Do not build docs for now
- imported package x11-proto-devel

